@@ -9,27 +9,27 @@ setMethodS3("convertToUnique", "AffymetrixCelSet", function(this, ..., tags="*",
   tags[tags == "*"] <- "UNQ"
 
   # Argument 'force':
-  force <- Arguments$getLogical(force);
+  force <- Arguments$getLogical(force)
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
-  verbose && enter(verbose, "Converting to unique CDF");
+  verbose && enter(verbose, "Converting to unique CDF")
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Already unique?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  cdf <- getCdf(this);
+  cdf <- getCdf(this)
 
   # Already done?
   if (isUniqueCdf(cdf)) {
-    verbose && cat(verbose, "Already based on a unique CDF");
-    verbose && exit(verbose);
-    return(invisible(this));
+    verbose && cat(verbose, "Already based on a unique CDF")
+    verbose && exit(verbose)
+    return(invisible(this))
   }
 
   verbose && enter(verbose, "Getting unique CDF")
@@ -39,38 +39,38 @@ setMethodS3("convertToUnique", "AffymetrixCelSet", function(this, ..., tags="*",
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Getting output directory
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  rootPath <- "probeData";
-  verbose && cat(verbose, "Output root: ", rootPath);
+  rootPath <- "probeData"
+  verbose && cat(verbose, "Output root: ", rootPath)
 
-  srcTags <- getTags(this, collapse=",");
-  verbose && cat(verbose, "Source tags: ", srcTags);
+  srcTags <- getTags(this, collapse=",")
+  verbose && cat(verbose, "Source tags: ", srcTags)
 
-  verbose && cat(verbose, "User tags: ", tags);
+  verbose && cat(verbose, "User tags: ", tags)
 
-  tags <- c(srcTags, tags);
-  tags <- tags[nzchar(tags)];
-  tags <- paste(tags, collapse=",");
-  verbose && cat(verbose, "Output tags: ", tags);
+  tags <- c(srcTags, tags)
+  tags <- tags[nzchar(tags)]
+  tags <- paste(tags, collapse=",")
+  verbose && cat(verbose, "Output tags: ", tags)
 
-  chipType <- getChipType(this, fullname=FALSE);
-  verbose && cat(verbose, "Chip type: ", chipType);
+  chipType <- getChipType(this, fullname=FALSE)
+  verbose && cat(verbose, "Chip type: ", chipType)
 
-  fullname <- paste(c(getName(this), tags), collapse=",");
-  verbose && cat(verbose, "Output fullname: ", fullname);
+  fullname <- paste(c(getName(this), tags), collapse=",")
+  verbose && cat(verbose, "Output fullname: ", fullname)
 
-  outputPath <- file.path(rootPath, fullname, chipType);
-  outputPath <- Arguments$getWritablePath(outputPath);
-  verbose && cat(verbose, "Output Path: ", outputPath);
+  outputPath <- file.path(rootPath, fullname, chipType)
+  outputPath <- Arguments$getWritablePath(outputPath)
+  verbose && cat(verbose, "Output Path: ", outputPath)
 
 
   # Expected output set
-  fullnames <- getFullNames(this);
+  fullnames <- getFullNames(this)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Already done?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Checking if dataset already exists");
+  verbose && enter(verbose, "Checking if dataset already exists")
 
   res <- tryCatch({
     # HB: Don't think argument 'checkChipType' makes a difference if
@@ -85,27 +85,27 @@ setMethodS3("convertToUnique", "AffymetrixCelSet", function(this, ..., tags="*",
     # WORKAROUND/TO BE REMOVED: R.utils (<= 1.19.0) will give an error
     # with extract() if length(fullnames) > length(res). /HB 2012-12-01
     if (length(res) >= length(fullnames)) {
-      res <- extract(res, fullnames, onMissing="drop", onDuplicates="error");
+      res <- extract(res, fullnames, onMissing="drop", onDuplicates="error")
     }
 
     # Is output set complete?
-    missing <- setdiff(fullnames, getFullNames(res));
+    missing <- setdiff(fullnames, getFullNames(res))
     if (length(missing) == 0) {
       if (!force) {
-        verbose && cat(verbose, "Detected existing output dataset. Skipping.");
-        verbose && exit(verbose);
-        verbose && exit(verbose);
-        return(invisible(res));
+        verbose && cat(verbose, "Detected existing output dataset. Skipping.")
+        verbose && exit(verbose)
+        verbose && exit(verbose)
+        return(invisible(res))
       }
-      verbose && cat(verbose, "Detected existing output dataset, but will force reprocessing.");
+      verbose && cat(verbose, "Detected existing output dataset, but will force reprocessing.")
     } else if (length(missing) > 0) {
-      verbose && cat(verbose, "Detected partial output dataset.");
+      verbose && cat(verbose, "Detected partial output dataset.")
     }
   }
 
   # Not needed anymore
   res <- NULL;   # Not needed anymore
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -216,54 +216,13 @@ setMethodS3("convertToUnique", "AffymetrixCelSet", function(this, ..., tags="*",
   res <- NULL
 
   res <- AffymetrixCelSet$byName(fullname, cdf=cdfUnique,
-                                      checkChipType=FALSE, verbose=verbose);
+                                      checkChipType=FALSE, verbose=verbose)
 
   # Extract samples in the same order as they appear in the input
   # data set, and if more were found, drop those.
-  res <- extract(res, fullnames, onMissing="error", onDuplicates="error");
+  res <- extract(res, fullnames, onMissing="error", onDuplicates="error")
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  invisible(res);
+  invisible(res)
 }, protected=TRUE) # convertToUnique()
-
-
-############################################################################
-# HISTORY:
-# 2015-11-20 [HB]
-# o Now also convertToUnique() acknowledge asterisk tags.
-# 2012-11-30 [HB]
-# o BUG FIX/ROBUSTNESS: convertToUnique() for AffymetrixCelSet would
-#   return all CEL files found in the output directory, not just the ones
-#   corresponding to the input set, and possibly in a different order.
-# 2011-03-28 [HB]
-# o Now convertToUnique() for AffymetrixCelSet skips already processed
-#   files in partially processed data sets.  Previously it would give
-#   an error if only some output files existed.
-# 2011-02-24 [HB]
-# o Now convertToUnique() for AffymetrixCelSet searches for already
-#   available data sets using the aroma-wide search rules.  Before it
-#   assumed it would always be located in probeData/, but with the new
-#   rules it can also be in probeData,<tags>/.
-# 2010-05-13 [HB]
-# o Yday's fixes had some hiccups.
-# 2010-05-12 [HB]
-# o BUG FIX: convertToUnique() for AffymetrixCelSet would not recognize
-#   Windows Shortcut links.
-# o ROBUSTNESS: Now convertToUnique() for AffymetrixCelSet writes to
-#   temporary files which are renamed when complete.  This lowers the
-#   risk of generating incomplete files.
-# o CLEAN UP: Code cleanup.
-# 2009-03-18 [MR]
-# o changed the way CEL headers are made ... it now uses cdfHeaderToCelHeader()
-# 2008-12-08 [MR]
-# o fixed small bug when operating on raw data
-# 2008-12-04 [MR]
-# o fixed small bug when previous dataset not available
-# 2008-11-28 [HB]
-# o Tidying up code.
-# o Replaced try() with tryCatch() statement.  I consider try() to be
-#   obsolete.
-# 2008-11-11 [MR]
-# o Created.
-############################################################################
