@@ -3,48 +3,48 @@
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 sourceTestScript <- function(pathname, devel=FALSE, ...) {
   # Argument 'devel':
-  devel <- Arguments$getLogical(devel);
+  devel <- Arguments$getLogical(devel)
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Setup
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Enable support for sibling root paths?
   if (devel) {
-    key <- "devel/dropRootPathTags";
-    oopts <- setOption(aromaSettings, key, TRUE);
+    key <- "devel/dropRootPathTags"
+    oopts <- setOption(aromaSettings, key, TRUE)
     on.exit({
-      setOption(aromaSettings, key, oopts);
-    }, add=TRUE);
+      setOption(aromaSettings, key, oopts)
+    }, add=TRUE)
     # Print settings
-    print(getOption(aromaSettings, key));
+    print(getOption(aromaSettings, key))
   }
 
   # Use special file cache for testing
-  library("R.cache");
-  opath <- getCacheRootPath();
+  library("R.cache")
+  opath <- getCacheRootPath()
   on.exit({
-    setCacheRootPath(opath);
-  }, add=TRUE);
-  setCacheRootPath(".Rcache");
+    setCacheRootPath(opath)
+  }, add=TRUE)
+  setCacheRootPath(".Rcache")
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Process
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  cat("** PATHNAME: ", pathname, "\n", sep="");
+  cat("** PATHNAME: ", pathname, "\n", sep="")
   tryCatch({
-    pathname <- Arguments$getReadablePathname(pathname);
-    source(pathname, echo=TRUE);
-    cat("** PATHNAME DONE: ", pathname, "\n", sep="");
+    pathname <- Arguments$getReadablePathname(pathname)
+    source(pathname, echo=TRUE)
+    cat("** PATHNAME DONE: ", pathname, "\n", sep="")
   }, error = function(ex) {
-    cat("************************************************\n");
-    cat("** ", rep(c(" ER", "ROR "), times=6), " **\n", sep="");
-    print(ex);
-    print(sessionInfo());
-    cat("************************************************\n");
-    cat("** PATHNAME FAILED: ", pathname, "\n", sep="");
-  });
-  gc();
+    cat("************************************************\n")
+    cat("** ", rep(c(" ER", "ROR "), times=6), " **\n", sep="")
+    print(ex)
+    print(sessionInfo())
+    cat("************************************************\n")
+    cat("** PATHNAME FAILED: ", pathname, "\n", sep="")
+  })
+  gc()
 } # sourceTestScript()
 
 
@@ -53,22 +53,22 @@ sourceTestSet <- function(path, ...) {
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'path':
-  path <- Arguments$getReadablePath(path);
+  path <- Arguments$getReadablePath(path)
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # For each test script...
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  pathnames <- list.files(path=path, pattern="[.]R$", full.names=TRUE);
-  cat("TEST SCRIPTS: \n");
-  print(pathnames);
+  pathnames <- list.files(path=path, pattern="[.]R$", full.names=TRUE)
+  cat("TEST SCRIPTS: \n")
+  print(pathnames)
 
   for (pathname in pathnames) {
     if (regexpr("hetero", pathname) != -1)
-      next;
+      next
     if (regexpr("expectile", pathname) != -1)
-      next;
-    sourceTestScript(pathname, ...);
-  } # for (pathname ...);
+      next
+    sourceTestScript(pathname, ...)
+  } # for (pathname ...)
 } # sourceTestSet()
 
 
@@ -77,64 +77,64 @@ sourceTestGroups <- function(groups, pattern=".*", order=c("auto", "asis", "reve
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'groups':
-  groups <- Arguments$getCharacters(groups);
+  groups <- Arguments$getCharacters(groups)
 
   # Argument 'pattern':
-  pattern <- Arguments$getRegularExpression(pattern);
+  pattern <- Arguments$getRegularExpression(pattern)
 
   # Argument 'order':
-  order <- match.arg(order);
+  order <- match.arg(order)
 
   # Argument 'nbrOfSets':
   if (!is.null(nbrOfSets)) {
-    nbrOfSets <- Arguments$getInteger(nbrOfSets, range=c(1,Inf));
-    if (order == "auto") order <- "random";
+    nbrOfSets <- Arguments$getInteger(nbrOfSets, range=c(1,Inf))
+    if (order == "auto") order <- "random"
   }
 
   if (order == "auto") {
-    order <- "asis";
+    order <- "asis"
   }
 
-  rootPath <- Arguments$getReadablePath("testScripts/");
+  rootPath <- Arguments$getReadablePath("testScripts/")
   for (group in groups) {
-    path <- file.path(rootPath, group);
-    path <- Arguments$getReadablePath(path);
+    path <- file.path(rootPath, group)
+    path <- Arguments$getReadablePath(path)
 
     # Find all test sets
-    pathnames <- list.files(path=path, recursive=TRUE, full.names=TRUE);
-    paths <- dirname(pathnames);
-    paths <- unique(paths);
-    paths <- paths[sapply(paths, FUN=isDirectory)];
+    pathnames <- list.files(path=path, recursive=TRUE, full.names=TRUE)
+    paths <- dirname(pathnames)
+    paths <- unique(paths)
+    paths <- paths[sapply(paths, FUN=isDirectory)]
 
     # Filter
-    paths <- grep(pattern, paths, value=TRUE);
-    cat("Filtered test sets:\n");
-    print(paths);
+    paths <- grep(pattern, paths, value=TRUE)
+    cat("Filtered test sets:\n")
+    print(paths)
 
     if (order == "reverse") {
-      paths <- rev(paths);
+      paths <- rev(paths)
     } else if (order == "random") {
-      paths <- sample(paths);
+      paths <- sample(paths)
     }
-    cat("All test sets:\n");
-    print(paths);
+    cat("All test sets:\n")
+    print(paths)
 
     if (!is.null(nbrOfSets)) {
-      cat("Subsetted test sets:\n");
-      paths <- paths[1:nbrOfSets];
-      print(paths);
+      cat("Subsetted test sets:\n")
+      paths <- paths[1:nbrOfSets]
+      print(paths)
     }
 
     # For each test set...
     for (path in paths) {
-      sourceTestSet(path, ...);
+      sourceTestSet(path, ...)
     }
-  } # for (groups ...);
+  } # for (groups ...)
 } # sourceTestGroups()
 
 
 launchTestGroups <- function(groups="system", ...) {
-  sourceTestGroups(groups=groups, ...);
+  sourceTestGroups(groups=groups, ...)
 } # launchTestGroups()
 
 
